@@ -20,9 +20,14 @@ CHANGELOG = ChangeLog(
         'Added default and built values for members',
         'Added required members',
         'Added TC global',
-        )
+        ),
+    Version('0.3.1',
+        'Added the member attribute extensions',
+        ),
 )
 
+__doc__ += '\n' + str(CHANGELOG)
+
 if __name__ == '__main__':
     print CHANGELOG
 
